import PlayerObject from "./Player";
import DiscPropertiesObject from "./DiscPropertiesObject";
import ScoresObject from "./ScoresObject";

interface RoomObject {
  sendChat(message: string, targetId?: number): void;
  setPlayerAdmin(playerId: number, admin: boolean): void;
  setPlayerTeam(playerId: number, team: number): void;
  kickPlayer(playerId: number, reason: string | null, ban: boolean): void;
  clearBan(playerId: number): void;
  clearBans(): void;
  setScoreLimit(limit: number): void;
  setTimeLimit(limitInMinutes: number): void;
  setCustomStadium(stadiumFileContents: string): void;
  setDefaultStadium(
    stadiumName:
      | "Classic"
      | "Easy"
      | "Small"
      | "Big"
      | "Rounded"
      | "Hockey"
      | "Big Hockey"
      | "Big Easy"
      | "Big Rounded"
      | "Huge"
  ): void;
  setTeamsLock(locked: boolean): void;
  setTeamColors(
    team: number,
    angle: number,
    textColor: number,
    colors: number[]
  ): void;
  startGame(): void;
  stopGame(): void;
  pauseGame(pauseState: boolean): void;
  getPlayer(playerId: number): PlayerObject;
  getPlayerList(): PlayerObject[];
  getScores(): ScoresObject;
  getBallPosition(): { x: number, y: number };
  startRecording(): void;
  stopRecording(): Uint16Array;
  setPassword(password: string): void;
  setRequireRecaptcha(required: boolean): void;
  reorderPlayers(playerIdList: number[], moveToTop: boolean): void;
  sendAnnouncement(
    message: string,
    targetId?: number,
    color?: number,
    style?: string,
    sound?: number
  ): void;
  setKickRateLimit(min: number, rate: number, burst: number): void;
  setPlayerAvatar(playerId: number, avatar: string): void;
  setDiscProperties(discIndex: number, properties: DiscPropertiesObject): void;
  getDiscProperties(discIndex: number): DiscPropertiesObject;
  setPlayerDiscProperties(playerId: number, properties: DiscPropertiesObject): void;
  getPlayerDiscProperties(playerId: number): DiscPropertiesObject;
  getDiscProperties(playerId: number): DiscPropertiesObject;
  getDiscCount(): number;
}

export default RoomObject;
